| Title: | Play a Game of 2048 in the Console |
|---|---|
| Description: | Generates a game of 2048 that can be played in the console. Supports grids of arbitrary sizes, undoing the last move, and resuming a game that was exited during the current session. |
| Authors: | Alexander Rossell Hayes [aut, cre, cph] (ORCID: <https://orcid.org/0000-0001-9412-0457>) |
| Maintainer: | Alexander Rossell Hayes <[email protected]> |
| License: | MIT + file LICENSE |
| Version: | 0.2.1 |
| Built: | 2026-06-05 06:29:49 UTC |
| Source: | https://github.com/rossellhayes/twenty48 |
Interact with the game by typing commands into the console and pressing enter.
play_2048(size = 4, dynamic = rstudioapi::isAvailable()) resume_2048()play_2048(size = 4, dynamic = rstudioapi::isAvailable()) resume_2048()
size |
An integer giving the grid's dimensions.
Defaults to |
dynamic |
If |
Generates an interactive game of 2048 in the console.
play_2048() play_2048(size = 5)play_2048() play_2048(size = 5)